goLanguageServer: change survey prompt probability to 2.75%

As discussed earlier. Not sure why I decided to use 5%.

Change-Id: Ia8e2963aa86e5887d0e01ef45a0c799208c9d42d
Reviewed-on: https://go-review.googlesource.com/c/vscode-go/+/246762
Run-TryBot: Rebecca Stambler <rstambler@golang.org>
TryBot-Result: kokoro <noreply+kokoro@google.com>
Reviewed-by: Hyang-Ah Hana Kim <hyangah@gmail.com>
diff --git a/src/goLanguageServer.ts b/src/goLanguageServer.ts
index c003d60..22c0938 100644
--- a/src/goLanguageServer.ts
+++ b/src/goLanguageServer.ts
@@ -890,10 +890,10 @@
 	}
 	// This is the first activation this month (or ever), so decide if we
 	// should prompt the user. This is done by generating a random number in
 	// the range [0, 1) and checking if it is < 0.05, for a 5% probability.
 	// We then randomly pick a day in the rest of the month on which to prompt
 	// the user.
-	cfg.promptThisMonth = Math.random() < 0.05;
+	cfg.promptThisMonth = Math.random() < 0.0275;
 	if (cfg.promptThisMonth) {
 		// end is the last day of the month, day is the random day of the
 		// month on which to prompt.
@@ -890,10 +890,10 @@
 	// This is the first activation this month (or ever), so decide if we
 	// should prompt the user. This is done by generating a random number in
-	// the range [0, 1) and checking if it is < 0.05, for a 5% probability.
+	// the range [0, 1) and checking if it is < 0.0275, for a 2.75% probability.
 	// We then randomly pick a day in the rest of the month on which to prompt
 	// the user.